@@ -2,13 +2,13 @@
 
 __author__ = "Frank J. Tobin, ftobin@neverending.org"
 __credits__ = "Tony Meyer, Dreas von Donselaar, all the Pyzor contributors."
-__version__ = "0.7.0"
+__version__ = "1.1.2"
 
 import hashlib
 
-proto_name = 'pyzor'
+proto_name = "pyzor"
 proto_version = 2.1
-anonymous_user = 'anonymous'
+anonymous_user = "anonymous"
 
 # We would like to use sha512, but that would mean that all the digests
 # changed, so for now, we stick with sha1 (which is the same as the old
@@ -22,39 +22,43 @@ MAX_TIMESTAMP_DIFFERENCE = 300  # seconds
 
 class CommError(Exception):
     """Something in general went wrong with the transaction."""
-    pass
+
+    code = 400
 
 
 class ProtocolError(CommError):
     """Something is wrong with talking the protocol."""
-    pass
+
+    code = 400
 
 
 class TimeoutError(CommError):
     """The connection timed out."""
-    pass
+
+    code = 504
 
 
 class IncompleteMessageError(ProtocolError):
     """A complete requested was not received."""
+
     pass
 
 
 class UnsupportedVersionError(ProtocolError):
     """Client is using an unsupported protocol version."""
+
     pass
 
 
 class SignatureError(CommError):
     """Unknown user, signature on msg invalid, or not within allowed time
     range."""
+
     pass
 
 
 class AuthorizationError(CommError):
     """The signature was valid, but the user is not permitted to do the
     requested action."""
+
     pass
-
-
-
