@@ -15,13 +15,14 @@ appropriate interval.
 from pyzor.engines import gdbm_
 from pyzor.engines import mysql
 from pyzor.engines import redis_
+from pyzor.engines import redis_v0
 
 
 __all__ = ["database_classes"]
 
-database_classes = {"gdbm": gdbm_.handle,
-                    "mysql": mysql.handle,
-                    "redis": redis_.handle,
-                    }
-
-
+database_classes = {
+    "gdbm": gdbm_.handle,
+    "mysql": mysql.handle,
+    "redis_v0": redis_v0.handle,
+    "redis": redis_.handle,
+}
