@@ -7,8 +7,9 @@ from collections import namedtuple
 
 __all__ = ["DBHandle", "DatabaseError", "Record", "BaseEngine"]
 
-DBHandle = namedtuple("DBHandle", ["single_threaded", "multi_threaded",
-                                   "multi_processing", "prefork"])
+DBHandle = namedtuple(
+    "DBHandle", ["single_threaded", "multi_threaded", "multi_processing", "prefork"]
+)
 
 
 class DatabaseError(Exception):
@@ -20,8 +21,16 @@ class Record(object):
     r = report (spam)
     wl = whitelist
     """
-    def __init__(self, r_count=0, wl_count=0, r_entered=None,
-                 r_updated=None, wl_entered=None, wl_updated=None):
+
+    def __init__(
+        self,
+        r_count=0,
+        wl_count=0,
+        r_entered=None,
+        r_updated=None,
+        wl_entered=None,
+        wl_updated=None,
+    ):
         self.r_count = r_count
         self.wl_count = wl_count
         self.r_entered = r_entered
@@ -31,7 +40,7 @@ class Record(object):
 
     def wl_increment(self):
         # overflow prevention
-        if self.wl_count < sys.maxint:
+        if self.wl_count < sys.maxsize:
             self.wl_count += 1
         if self.wl_entered is None:
             self.wl_entered = datetime.datetime.now()
@@ -39,7 +48,7 @@ class Record(object):
 
     def r_increment(self):
         # overflow prevention
-        if self.r_count < sys.maxint:
+        if self.r_count < sys.maxsize:
             self.r_count += 1
         if self.r_entered is None:
             self.r_entered = datetime.datetime.now()
@@ -54,6 +63,7 @@ class Record(object):
 
 class BaseEngine(object):
     """Base class for Pyzor engines."""
+
     absolute_source = True
     handles_one_step = False
 
